import { useState, useEffect } from 'react';
import { Star, UserRound, Search, CalendarClock, Phone, Shield, Activity } from 'lucide-react';
import { useLanguage } from '@/lib/LanguageContext';
import MobileOptimizedHeroImage from '@/components/ui/mobile-optimized-hero-image';

export default function HeroSection() {
  const { t } = useLanguage();
  const [scrollY, setScrollY] = useState(0);

  // Critical image preloading removed - handled by mobile optimized component

  useEffect(() => {
    const handleScroll = () => setScrollY(window.scrollY);
    window.addEventListener('scroll', handleScroll);
    return () => window.removeEventListener('scroll', handleScroll);
  }, []);

  const handleClick = (e: React.MouseEvent<HTMLAnchorElement>, targetId: string) => {
    e.preventDefault();
    const element = document.getElementById(targetId);
    if (element) {
      element.scrollIntoView({ behavior: 'smooth' });
    }
  };

  const stats = [
    { value: "4.8", label: t('hero.stats.rating') },
    { value: "24/7", label: t('hero.stats.availability') },
    { value: "15+", label: t('hero.stats.experience') },
    { value: "98%", label: t('hero.stats.satisfaction') }
  ];

  const availableDoctors = [
    { name: "Dr. Maria Rodriguez", specialty: "Internal Medicine" },
    { name: "Dr. Carlos Mendez", specialty: "Family Medicine" },
    { name: "Dr. Ana Gutierrez", specialty: "Cardiology" }
  ];

  const insuranceCompanies = [
    { name: "Amerihealth Caritas", color: "#1f4e79" },
    { name: "Aetna Commercial Health", color: "#d20962" },
    { name: "Aetna Medicare", color: "#7d3f98" },
    { name: "Oscar", color: "#0066cc" },
    { name: "Preferred Care Partners", color: "#2563eb" },
    { name: "Preferred Care Network", color: "#059669" },
    { name: "Soliz Health Plans", color: "#0891b2" },
    { name: "Community Care Plan", color: "#1e40af" },
    { name: "United Healthcare", color: "#003C71" }
  ];

  // Parallax calculations
  const bgTransform = `translateY(${scrollY * 0.5}px)`;
  const contentTransform = `translateY(${scrollY * 0.3}px)`;
  const circleTransform = `translateY(${scrollY * -0.2}px)`;
  const doctorCardTransform = `translateY(${scrollY * -0.12}px)`;

  return (
    <section className="relative h-screen min-h-[900px] flex items-start pt-24 md:pt-32 overflow-hidden bg-gradient-to-b from-sky-50 to-blue-50 parallax-container">
      {/* Announcement ticker - simplified and always visible */}
      <div className="absolute top-6 md:top-8 left-0 right-0 w-full py-2 bg-white/30 backdrop-blur-sm z-20 overflow-hidden">
        <div 
          className="announcement-ticker"
          role="region"
          aria-label="Contact information"
        >
          <div className="ticker-content flex whitespace-nowrap items-center">
            {/* Contact information with responsive sizing */}
            <div className="flex items-center gap-2 mx-4 text-primary font-medium text-xs md:text-sm">
              <Phone className="h-3 w-3 md:h-4 md:w-4 flex-shrink-0" aria-hidden="true" />
              <span>305-315-8289</span>
            </div>
            <div className="h-1 w-1 rounded-full bg-primary/50 mx-2 flex-shrink-0" aria-hidden="true"></div>
            <div className="flex items-center gap-2 mx-4 text-primary font-medium text-xs md:text-sm">
              <Shield className="h-3 w-3 md:h-4 md:w-4 flex-shrink-0" aria-hidden="true" />
              <span className="hidden md:inline">9240 SW 72nd St Ste 238, Miami, FL</span>
              <span className="md:hidden">Kendall, Miami</span>
            </div>
            <div className="h-1 w-1 rounded-full bg-primary/50 mx-2 flex-shrink-0" aria-hidden="true"></div>
            <div className="hidden md:flex items-center gap-2 mx-4 text-primary font-medium text-sm">
              <CalendarClock className="h-4 w-4 flex-shrink-0" aria-hidden="true" />
              <span>{t('announcement.opening')}</span>
            </div>
            
            {/* Duplicate for continuous scrolling */}
            <div className="flex items-center gap-2 mx-4 text-primary font-medium text-xs md:text-sm" aria-hidden="true">
              <Phone className="h-3 w-3 md:h-4 md:w-4 flex-shrink-0" />
              <span>305-315-8289</span>
            </div>
            <div className="h-1 w-1 rounded-full bg-primary/50 mx-2 flex-shrink-0"></div>
            <div className="flex items-center gap-2 mx-4 text-primary font-medium text-xs md:text-sm">
              <Shield className="h-3 w-3 md:h-4 md:w-4 flex-shrink-0" />
              <span className="hidden md:inline">9240 SW 72nd St Ste 238, Miami, FL</span>
              <span className="md:hidden">Kendall, Miami</span>
            </div>
            <div className="h-1 w-1 rounded-full bg-primary/50 mx-2 flex-shrink-0"></div>
            <div className="hidden md:flex items-center gap-2 mx-4 text-primary font-medium text-sm">
              <CalendarClock className="h-4 w-4 flex-shrink-0" />
              <span>{t('announcement.opening')}</span>
            </div>
          </div>
        </div>
        
        {/* Screen reader only static content */}
        <div className="sr-only">
          Contact: 305-315-8289. Address: 9240 SW 72nd St Ste 238, Miami, FL
        </div>
      </div>
      
      {/* Background elements with parallax - hidden on mobile */}
      <div 
        className="absolute inset-0 z-0 bg-blue-100/20 parallax-bg parallax-slow hidden md:block"
        style={{ transform: bgTransform }}
        aria-hidden="true"
      >
        <div 
          className="absolute top-0 right-0 w-full h-64 bg-white/30 rounded-full blur-3xl transform translate-x-1/3 -translate-y-1/2"
          style={{ transform: `${circleTransform} translate(30%, -50%)` }}
        ></div>
        <div 
          className="absolute bottom-0 left-0 w-full h-64 bg-blue-200/20 rounded-full blur-3xl transform -translate-x-1/3 translate-y-1/2"
          style={{ transform: `${circleTransform} translate(-30%, 50%)` }}
        ></div>
      </div>
      
      {/* Floating available doctors card - positioned at bottom-left corner of doctor image */}
      <div 
        className="absolute bottom-[254px] right-[400px] available-doctors w-48 float z-50 hidden xl:block"
        style={{ transform: doctorCardTransform }}
      >
        <div className="mb-1 font-medium text-xs">Available Doctors</div>
        
        <div className="flex flex-wrap gap-1 mb-2">
          {availableDoctors.slice(0, 2).map((doctor, index) => (
            <div key={index} className="flex items-center gap-1 bg-white/90 rounded-full px-2 py-1 text-xs">
              <div className="w-4 h-4 rounded-full bg-primary/10 flex items-center justify-center text-primary">
                <UserRound className="h-2 w-2" />
              </div>
              <span className="font-medium text-xs truncate">{doctor.name.split(' ')[1]}</span>
            </div>
          ))}
        </div>
        
        <div className="relative">
          <label htmlFor="doctor-search" className="sr-only">
            Search for available doctors by name or specialty
          </label>
          <input 
            id="doctor-search"
            type="text" 
            placeholder="Search Doctor" 
            className="w-full text-xs py-1 pl-6 pr-2 rounded-full border border-secondary/20 focus:outline-none focus:ring-1 focus:ring-primary"
            aria-label="Search for available doctors by name or specialty"
          />
          <Search className="absolute left-2 top-1 h-3 w-3 text-muted-foreground" aria-hidden="true" />
        </div>
      </div>

      <div className="relative max-w-[90rem] mx-auto w-full px-4 sm:px-6 lg:px-8 z-20">
        <div className="grid grid-cols-1 lg:grid-cols-2 gap-12 items-center">
          <div 
            className="fade-in-group"
          >
            <div className="inline-flex items-center px-4 py-2 rounded-full bg-white/80 backdrop-blur-sm shadow-sm text-primary font-medium text-sm mb-5">
              <Activity className="w-4 h-4 mr-2" />
              {t('hero.badge')}
            </div>
            
            <h1 className="text-3xl md:text-4xl lg:text-5xl font-bold text-foreground mb-6 leading-tight">
              <span className="text-primary">{t('hero.headline.part1')}</span> {t('hero.headline.tagline')} <span className="bg-orange-100/80 px-3 py-1 rounded-lg inline-block">{t('hero.headline.emphasis')}</span>
            </h1>
            
            <p className="text-base md:text-lg text-muted-foreground mb-6 max-w-md text-balance">
              {t('hero.subtitle')}
            </p>
            
            <div className="flex flex-col sm:flex-row gap-3 mb-8">
              <a 
                href="https://consumer.scheduling.athena.io/?locationId=32475-1&practitionerId=32475-1"
                target="_blank"
                rel="noopener noreferrer"
                className="btn-primary inline-flex items-center justify-center text-sm"
              >
                <CalendarClock className="mr-2 h-4 w-4" />
                {t('hero.cta.appointment')}
              </a>
              
              <a 
                href="/services"
                className="btn-outline inline-flex items-center justify-center text-sm"
              >
                <Activity className="mr-2 h-4 w-4" />
                {t('hero.cta.services')}
              </a>
            </div>
            
            <div className="flex flex-wrap justify-center md:justify-start gap-3 mt-8">
              {stats.map((stat, index) => (
                <div key={index} className="stat-card float py-3 px-4 w-[44%] md:w-auto md:min-w-[110px] border border-[#1A2D55]/20">
                  <div className="text-lg md:text-xl font-semibold text-primary">{stat.value}</div>
                  <div className="text-xs text-gray-500 mt-1">{stat.label}</div>
                </div>
              ))}
            </div>
          </div>
          
          <div className="hidden lg:block relative lg:pl-12 xl:pl-24">
            {/* Doctor image - positioned relative to parent */}
            <div className="relative ml-auto mr-0 w-[480px] h-[580px]">
              {/* Floating decorative element - centered behind doctor image */}
              <div 
                className="absolute right-[-20px] top-[60px] w-[520px] h-[520px] rounded-full bg-accent/20 backdrop-blur-md float-slow z-10"
                aria-hidden="true"
              ></div>

              
              {/* Doctor image container - Mobile LCP Optimized */}
              <figure 
                className="absolute right-0 top-16 rounded-3xl overflow-hidden w-[480px] h-[480px] z-[9999]"
                role="img"
                aria-labelledby="hero-doctors-caption"
              >
                <MobileOptimizedHeroImage
                  src="/images/hero-doctors-optimized.webp"
                  mobileSrc="/images/hero-doctors-optimized.webp"
                  alt="Three professional doctors from Veritas Medical Group standing together in white coats, smiling confidently while representing comprehensive primary care services in Kendall, Miami"
                  width={480}
                  height={480}
                  style={{
                    maskImage: 'linear-gradient(to top, transparent 0%, rgba(0,0,0,1) 20%, rgba(0,0,0,1) 100%)',
                    WebkitMaskImage: 'linear-gradient(to top, transparent 0%, rgba(0,0,0,1) 20%, rgba(0,0,0,1) 100%)'
                  }}
                />
                <figcaption id="hero-doctors-caption" className="sr-only">
                  Professional medical team at Veritas Medical Group providing comprehensive healthcare services in Kendall, Miami
                </figcaption>
              </figure>
            </div>
          </div>
        </div>
      </div>
      
      {/* Insurance slider positioned in hero section - simplified and always visible */}
      <div className="absolute bottom-16 md:bottom-20 lg:bottom-24 left-0 right-0 py-4 z-10">
        <div className="max-w-[90rem] mx-auto">
          <div className="slider-container">
            {/* Mobile version - shorter list */}
            <div className="md:hidden">
              <div className="flex space-x-6 insurance-slider">
                {[
                  { name: "Aetna", color: "#d20962" },
                  { name: "United Healthcare", color: "#003C71" },
                  { name: "Oscar", color: "#0066cc" },
                  { name: "Preferred Care", color: "#2563eb" }
                ].map((company, index) => (
                  <div 
                    key={index} 
                    className="flex-shrink-0 px-3"
                  >
                    <div className="font-medium text-xs" style={{ color: company.color }}>{company.name}</div>
                  </div>
                ))}
                
                {/* Duplicate for animation */}
                {[
                  { name: "Aetna", color: "#d20962" },
                  { name: "United Healthcare", color: "#003C71" },
                  { name: "Oscar", color: "#0066cc" },
                  { name: "Preferred Care", color: "#2563eb" }
                ].map((company, index) => (
                  <div 
                    key={`mobile-duplicate-${index}`} 
                    className="flex-shrink-0 px-3"
                  >
                    <div className="font-medium text-xs" style={{ color: company.color }}>{company.name}</div>
                  </div>
                ))}
              </div>
            </div>

            {/* Desktop version - full list */}
            <div className="hidden md:flex space-x-16 insurance-slider">
              {insuranceCompanies.map((company, index) => (
                <div 
                  key={index} 
                  className="flex-shrink-0 px-4"
                >
                  <div className="font-medium text-sm" style={{ color: company.color }}>{company.name}</div>
                </div>
              ))}
              
              {/* Duplicate for infinite scroll effect */}
              {insuranceCompanies.map((company, index) => (
                <div 
                  key={`desktop-duplicate-${index}`} 
                  className="flex-shrink-0 px-4"
                >
                  <div className="font-medium text-sm" style={{ color: company.color }}>{company.name}</div>
                </div>
              ))}
            </div>
          </div>
        </div>
      </div>
    </section>
  );
}